from setuptools import setup

setup(
    name = 'pyril',
    version = '1.0.0',
    description = 'Mirror package of ril, please install that instead.',
    install_requires = [
        'ril',
    ],
    long_description='Mirror package of ril, please install that instead.',
)
